'use strict';

var view = require('@codemirror/view');
var language = require('@codemirror/language');
var highlight = require('@lezer/highlight');

// VSCode Dark theme color definitions
const background = '#1e1e1e', foreground = '#9cdcfe', caret = '#c6c6c6', selection = '#6199ff2f', selectionMatch = '#72a1ff59', lineHighlight = '#ffffff0f', gutterBackground = '#1e1e1e', gutterForeground = '#838383', gutterActiveForeground = '#ffffff', keywordColor = '#569cd6', controlKeywordColor = '#c586c0', variableColor = '#9cdcfe', classTypeColor = '#4ec9b0', functionColor = '#dcdcaa', numberColor = '#b5cea8', operatorColor = '#d4d4d4', regexpColor = '#d16969', stringColor = '#ce9178', commentColor = '#6a9955', invalidColor = '#ff0000';
// Define the editor theme styles for VSCode Dark
const vsCodeDarkTheme = view.EditorView.theme({
    '&': {
        color: foreground,
        backgroundColor: background,
        fontFamily: 'Menlo, Monaco, Consolas, "Andale Mono", "Ubuntu Mono", "Courier New", monospace',
    },
    '.cm-content': {
        caretColor: caret,
    },
    '.cm-cursor, .cm-dropCursor': {
        borderLeftColor: caret,
    },
    '&.cm-focused > .cm-scroller > .cm-selectionLayer .cm-selectionBackground, .cm-selectionBackground, .cm-content ::selection': {
        backgroundColor: selection,
    },
    '.cm-searchMatch': {
        backgroundColor: selectionMatch,
        outline: `1px solid ${lineHighlight}`,
    },
    '.cm-activeLine': {
        backgroundColor: lineHighlight,
    },
    '.cm-gutters': {
        backgroundColor: gutterBackground,
        color: gutterForeground,
    },
    '.cm-activeLineGutter': {
        color: gutterActiveForeground,
    },
}, { dark: true });
// Define the highlighting style for code in the VSCode Dark theme
const vsCodeDarkHighlightStyle = language.HighlightStyle.define([
    {
        tag: [
            highlight.tags.keyword,
            highlight.tags.operatorKeyword,
            highlight.tags.modifier,
            highlight.tags.color,
            highlight.tags.constant(highlight.tags.name),
            highlight.tags.standard(highlight.tags.name),
            highlight.tags.standard(highlight.tags.tagName),
            highlight.tags.special(highlight.tags.brace),
            highlight.tags.atom,
            highlight.tags.bool,
            highlight.tags.special(highlight.tags.variableName),
        ],
        color: keywordColor,
    },
    { tag: [highlight.tags.controlKeyword, highlight.tags.moduleKeyword], color: controlKeywordColor },
    {
        tag: [
            highlight.tags.name,
            highlight.tags.deleted,
            highlight.tags.character,
            highlight.tags.macroName,
            highlight.tags.propertyName,
            highlight.tags.variableName,
            highlight.tags.labelName,
            highlight.tags.definition(highlight.tags.name),
        ],
        color: variableColor,
    },
    {
        tag: [
            highlight.tags.typeName,
            highlight.tags.className,
            highlight.tags.tagName,
            highlight.tags.number,
            highlight.tags.changed,
            highlight.tags.annotation,
            highlight.tags.self,
            highlight.tags.namespace,
        ],
        color: classTypeColor,
    },
    {
        tag: [highlight.tags.function(highlight.tags.variableName), highlight.tags.function(highlight.tags.propertyName)],
        color: functionColor,
    },
    { tag: [highlight.tags.number], color: numberColor },
    {
        tag: [highlight.tags.operator, highlight.tags.punctuation, highlight.tags.separator, highlight.tags.url, highlight.tags.escape, highlight.tags.regexp],
        color: operatorColor,
    },
    { tag: [highlight.tags.regexp], color: regexpColor },
    {
        tag: [highlight.tags.special(highlight.tags.string), highlight.tags.processingInstruction, highlight.tags.string, highlight.tags.inserted],
        color: stringColor,
    },
    { tag: [highlight.tags.meta, highlight.tags.comment], color: commentColor },
    { tag: highlight.tags.invalid, color: invalidColor },
    { tag: highlight.tags.strong, fontWeight: 'bold' },
    { tag: highlight.tags.emphasis, fontStyle: 'italic' },
    { tag: highlight.tags.strikethrough, textDecoration: 'line-through' },
    { tag: highlight.tags.link, color: commentColor, textDecoration: 'underline' },
]);
// Extension to enable the VSCode Dark theme (both the editor theme and the highlight style)
const vsCodeDark = [
    vsCodeDarkTheme,
    language.syntaxHighlighting(vsCodeDarkHighlightStyle),
];

exports.vsCodeDark = vsCodeDark;
exports.vsCodeDarkHighlightStyle = vsCodeDarkHighlightStyle;
exports.vsCodeDarkTheme = vsCodeDarkTheme;
