import { EditorView } from '@codemirror/view';
import { HighlightStyle, syntaxHighlighting } from '@codemirror/language';
import { tags } from '@lezer/highlight';

// VSCode Dark theme color definitions
const background = '#1e1e1e', foreground = '#9cdcfe', caret = '#c6c6c6', selection = '#6199ff2f', selectionMatch = '#72a1ff59', lineHighlight = '#ffffff0f', gutterBackground = '#1e1e1e', gutterForeground = '#838383', gutterActiveForeground = '#ffffff', keywordColor = '#569cd6', controlKeywordColor = '#c586c0', variableColor = '#9cdcfe', classTypeColor = '#4ec9b0', functionColor = '#dcdcaa', numberColor = '#b5cea8', operatorColor = '#d4d4d4', regexpColor = '#d16969', stringColor = '#ce9178', commentColor = '#6a9955', invalidColor = '#ff0000';
// Define the editor theme styles for VSCode Dark
const vsCodeDarkTheme = /*@__PURE__*/EditorView.theme({
    '&': {
        color: foreground,
        backgroundColor: background,
        fontFamily: 'Menlo, Monaco, Consolas, "Andale Mono", "Ubuntu Mono", "Courier New", monospace',
    },
    '.cm-content': {
        caretColor: caret,
    },
    '.cm-cursor, .cm-dropCursor': {
        borderLeftColor: caret,
    },
    '&.cm-focused > .cm-scroller > .cm-selectionLayer .cm-selectionBackground, .cm-selectionBackground, .cm-content ::selection': {
        backgroundColor: selection,
    },
    '.cm-searchMatch': {
        backgroundColor: selectionMatch,
        outline: `1px solid ${lineHighlight}`,
    },
    '.cm-activeLine': {
        backgroundColor: lineHighlight,
    },
    '.cm-gutters': {
        backgroundColor: gutterBackground,
        color: gutterForeground,
    },
    '.cm-activeLineGutter': {
        color: gutterActiveForeground,
    },
}, { dark: true });
// Define the highlighting style for code in the VSCode Dark theme
const vsCodeDarkHighlightStyle = /*@__PURE__*/HighlightStyle.define([
    {
        tag: [
            tags.keyword,
            tags.operatorKeyword,
            tags.modifier,
            tags.color,
            /*@__PURE__*/tags.constant(tags.name),
            /*@__PURE__*/tags.standard(tags.name),
            /*@__PURE__*/tags.standard(tags.tagName),
            /*@__PURE__*/tags.special(tags.brace),
            tags.atom,
            tags.bool,
            /*@__PURE__*/tags.special(tags.variableName),
        ],
        color: keywordColor,
    },
    { tag: [tags.controlKeyword, tags.moduleKeyword], color: controlKeywordColor },
    {
        tag: [
            tags.name,
            tags.deleted,
            tags.character,
            tags.macroName,
            tags.propertyName,
            tags.variableName,
            tags.labelName,
            /*@__PURE__*/tags.definition(tags.name),
        ],
        color: variableColor,
    },
    {
        tag: [
            tags.typeName,
            tags.className,
            tags.tagName,
            tags.number,
            tags.changed,
            tags.annotation,
            tags.self,
            tags.namespace,
        ],
        color: classTypeColor,
    },
    {
        tag: [/*@__PURE__*/tags.function(tags.variableName), /*@__PURE__*/tags.function(tags.propertyName)],
        color: functionColor,
    },
    { tag: [tags.number], color: numberColor },
    {
        tag: [tags.operator, tags.punctuation, tags.separator, tags.url, tags.escape, tags.regexp],
        color: operatorColor,
    },
    { tag: [tags.regexp], color: regexpColor },
    {
        tag: [/*@__PURE__*/tags.special(tags.string), tags.processingInstruction, tags.string, tags.inserted],
        color: stringColor,
    },
    { tag: [tags.meta, tags.comment], color: commentColor },
    { tag: tags.invalid, color: invalidColor },
    { tag: tags.strong, fontWeight: 'bold' },
    { tag: tags.emphasis, fontStyle: 'italic' },
    { tag: tags.strikethrough, textDecoration: 'line-through' },
    { tag: tags.link, color: commentColor, textDecoration: 'underline' },
]);
// Extension to enable the VSCode Dark theme (both the editor theme and the highlight style)
const vsCodeDark = [
    vsCodeDarkTheme,
    /*@__PURE__*/syntaxHighlighting(vsCodeDarkHighlightStyle),
];

export { vsCodeDark, vsCodeDarkHighlightStyle, vsCodeDarkTheme };
